;;;
;;; SRFI-4  homogeneous numeric vectors
;;;

;; Procedures of SRFI-4 are now defined in gauche.uvector.

(define-module srfi-4  (extend gauche.uvector))

